require "faraday"
require "faraday_middleware"

require "greentext/client/board"
require "greentext/client/post"

module Greentext
  # Public: The Client to access the API
  #
  # Examples
  #   client = Greentext::Client.new
  #   client.boards
  #   # => [#<Greentext::Board>, ...
  class Client
    include Greentext::Client::Board
    include Greentext::Client::Post

    attr_accessor :api_endpoint

    def initialize
      yield self if block_given?
    end

    # Public: Get the API Endpoint
    #
    # Returns a String containing a URI.
    def api_endpoint
      @api_endpoint ||= "http://a.4cdn.org/"
    end

    private

    # Private: Return the current Faraday connection or create a new one.
    #
    # Returns a Faraday session.
    def connection
      @connection ||= Faraday.new(url: api_endpoint) do |conn|
        conn.response :json
        conn.adapter Faraday.default_adapter
      end
    end

    # Private: Send a GET request to the path provided.
    #
    # path   - The path String under the base url to access.
    # params - An optional params Hash.
    #
    # Returns a Faraday Response object.
    def get(path, params={})
      connection.get(path, params).body
    end
  end
end
