require "greentext/board"

module Greentext
  class Client
    # Internal: Methods for interacting with boards.
    module Board
      # Public: List all the boards available.
      #
      # Returns an Array of Greentext::Board instances.
      def boards
        boards = get("/boards.json")["boards"]
        boards.map { |board| Greentext::Board.new(board) }
      end

      # Public: List all available threads in a board.
      #
      # board - A Greentext::Board object or a board name String/Symbol.
      #
      # Returns an Array of Greentext::Post instances.
      def threads(board)
        name = board.is_a?(Greentext::Board) ? board.name : board
        get("/#{name}/catalog.json")
          .map { |page| page["threads"] }.flatten
          .map { |thread| Greentext::Post.new(thread.merge("board" => board)) }
      end
    end
  end
end
