require "greentext/base"

module Greentext
  # Public: (Model) A 4chan post in a thread.
  class Post < Greentext::Base
    attr_reader :no
    attr_reader :resto
    attr_reader :board

    attr_epoch :time
    attr_epoch :last_modified

    attr_reader :trip
    attr_reader :id
    attr_reader :country
    attr_reader :country_name
    attr_reader :email
    attr_reader :subject, :sub
    attr_reader :comment, :com
    attr_reader :custom_spoiler
    attr_reader :omitted_posts
    attr_reader :omitted_images
    attr_reader :replies
    attr_reader :images
    attr_reader :capcode_replies
    attr_reader :tag
    attr_reader :semantic_url

    attr_predicate :sticky
    attr_predicate :closed
    attr_predicate :deleted
    attr_predicate :spoiler
    attr_predicate :bump_limit_reached, :bumplimit
    attr_predicate :image_limit_reached, :imagelimit

    attr_predicate :image, :filename

    # Public: Get information about the image attached to the post.
    #
    # Returns a Hash.
    def image
      if @attrs["tim"]
        {
          width: @attrs["w"],
          height: @attrs["h"],
          filename: @attrs["tim"],
          md5: @attrs["md5"],
          url: "https://i.4cdn.org/#{@attrs['board'].name}/" \
               "#{@attrs['tim']}#{@attrs['ext']}"
        }
      else
        {}
      end
    end

    # Public: Get information about the thumbnail of the image.
    #
    # Returns a Hash.
    def thumbnail
      if @attrs["tim"]
        { width: @attrs["tn_w"], height: @attrs["tn_h"],
          url: "https://t.4cdn.org/#{@attrs['board'].name}/" \
               "#{@attrs['tim']}s.jpg" 
        }
      else
        {}
      end
    end

    # Public: Determines if the post is OP.
    #
    # Returns a Boolean value.
    def op?
      @attrs["resto"] == 0
    end

    def expand
      Greentext.client.expand(self)
    end
  end
end
